@@ -9,15 +9,14 @@ import peewee as pw
 # Package information
 # ===================
 
-__version__ = "1.6.3"
+__version__ = "1.6.6"
 __project__ = "peewee_migrate"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "BSD"
 
 
 LOGGER: logging.Logger = logging.getLogger(__name__)
-LOGGER.addHandler(logging.StreamHandler())
-LOGGER.setLevel(logging.INFO)
+LOGGER.addHandler(logging.NullHandler())
 
 
 class MigrateHistory(pw.Model):
